<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://yukyhendiawan.com
 * @since      1.0.0
 *
 * @package    Live_Popup_Sales_Notification
 * @subpackage Live_Popup_Sales_Notification/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Live_Popup_Sales_Notification
 * @subpackage Live_Popup_Sales_Notification/admin
 * @author     Yuky Hendiawan <yukyhendiawan1998@gmail.com>
 */
class Live_Popup_Sales_Notification_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
	}

	/**
	 * Clear admin notices on specific plugin pages.
	 *
	 * This function removes all admin notices when the user is on either
	 * the "lpsn-settings" or "lpsn-information" page within the admin area.
	 *
	 * @global string $plugin_page The current plugin page slug.
	 */
	public function lpsn_clear_admin_notices() {
		global $plugin_page;

		// Check if the user is in the admin area.
		if ( is_admin() ) {
			// If the current page is either "lpsn-settings" or "lpsn-information".
			if ( 'lpsn-settings' === $plugin_page || 'lpsn-information' === $plugin_page ) {
				// Remove all admin notices for these specific pages.
				remove_all_actions( 'admin_notices' );
			}
		}
	}
}
