<?php
/**
 * Live Popup Sales Notification Config Class.
 *
 * This class manages the general configuration settings for the Live Popup Sales Notification plugin.
 *
 * @link       https://yukyhendiawan.com
 * @since      1.0.0
 *
 * @package    Live_Popup_Sales_Notification
 */

/**
 * Class Live_Popup_Sales_Notification_Config
 *
 * Manages general configuration settings for the Live Popup Sales Notification plugin.
 */
class Live_Popup_Sales_Notification_Config {

	/**
	 * Static array property to hold general configuration settings.
	 *
	 * @var array
	 */
	public static $general = array(
		// Enable or disable notifications on desktop devices.
		'enable_sales_notification_on_desktop' => 'on',

		// Enable or disable notifications on tablet devices.
		'enable_sales_notification_on_tablet'  => 'on',

		// Enable or disable notifications on mobile devices.
		'enable_sales_notification_on_mobile'  => 'on',
	);

	/**
	 * Static method to get a general configuration value.
	 *
	 * @param string $key The configuration key to retrieve.
	 * @return mixed The configuration value or null if the key doesn't exist.
	 */
	public static function get_general( $key ) {
		// Check if the key exists in the $general array and return the value, or null if it doesn't exist.
		return isset( self::$general[ $key ] ) ? self::$general[ $key ] : null;
	}
}

// Example usage:
// Accessing static array values without creating an object.
// echo Live_Popup_Sales_Notification_Config::get_general('enable_notifications_on_desktop_devices'); // Output: true.
