<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://yukyhendiawan.com
 * @since             1.0.0
 * @package           Live_Popup_Sales_Notification
 *
 * @wordpress-plugin
 * Plugin Name:       Live Sales Popup Notification for WooCommerce
 * Plugin URI:        https://yukyhendiawan.com
 * Description:       This plugin displays real-time sales and order notifications on your WooCommerce store, enhancing user engagement and boosting conversions.
 * Version:           1.1.2
 * Author:            Yuky Hendiawan
 * Author URI:        https://yukyhendiawan.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       live-popup-sales-notification
 * Domain Path:       /languages
 * Requires Plugins:  woocommerce
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'LIVE_POPUP_SALES_NOTIFICATION_VERSION', '1.1.2' );
define( 'LIVE_POPUP_SALES_NOTIFICATION_PREFIX', 'lpsn' );
define( 'LIVE_POPUP_SALES_NOTIFICATION_DIR_PATH', plugin_dir_path( __FILE__ ) );
define( 'LIVE_POPUP_SALES_NOTIFICATION_PLUGINS_URL', plugin_dir_url( __FILE__ ) );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-live-popup-sales-notification-activator.php
 */
function lpsn_activate() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-live-popup-sales-notification-activator.php';
	Live_Popup_Sales_Notification_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-live-popup-sales-notification-deactivator.php
 */
function lpsn_deactivate() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-live-popup-sales-notification-deactivator.php';
	Live_Popup_Sales_Notification_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'lpsn_activate' );
register_deactivation_hook( __FILE__, 'lpsn_deactivate' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-live-popup-sales-notification.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function lpsn_run_live() {

	$plugin = new Live_Popup_Sales_Notification();
	$plugin->run();
}
lpsn_run_live();
