<?php
/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://yukyhendiawan.com
 * @since      1.0.0
 *
 * @package    Live_Popup_Sales_Notification
 * @subpackage Live_Popup_Sales_Notification/public/partials
 */

// Retrieve the general settings option from the database.
$general_settings = get_option( 'lpsn_general_settings' );

// Check if notifications on desktop devices are enabled in the settings.
$get_enable_desktop_devices = isset( $general_settings['enable_sales_notification_on_desktop'] ) ? $general_settings['enable_sales_notification_on_desktop'] : Live_Popup_Sales_Notification_Config::get_general( 'enable_sales_notification_on_desktop' );

// Check if notifications on tablet devices are enabled in the settings.
$get_enable_tablet_devices = isset( $general_settings['enable_sales_notification_on_tablet'] ) ? $general_settings['enable_sales_notification_on_tablet'] : Live_Popup_Sales_Notification_Config::get_general( 'enable_sales_notification_on_tablet' );

// Check if notifications on mobile devices are enabled in the settings.
$get_enable_mobile_devices = isset( $general_settings['enable_sales_notification_on_mobile'] ) ? $general_settings['enable_sales_notification_on_mobile'] : Live_Popup_Sales_Notification_Config::get_general( 'enable_sales_notification_on_mobile' );

// Initialize the base class for the notification.
$dynamic_class = 'live-popup-sales-notification';

// Append a specific class if notifications are enabled for desktop devices.
if ( 'on' === $get_enable_desktop_devices ) {
	$dynamic_class .= ' lpsn-show-on-desktop';
}

// Append a specific class if notifications are enabled for tablet devices.
if ( 'on' === $get_enable_tablet_devices ) {
	$dynamic_class .= ' lpsn-show-on-tablet';
}

// Append a specific class if notifications are enabled for mobile devices.
if ( 'on' === $get_enable_mobile_devices ) {
	$dynamic_class .= ' lpsn-show-on-mobile';
}

?>

<section class="lpsn-container <?php echo esc_html( $dynamic_class ); ?>" style="display: none;">
	<div class="lpsn-box">
		<div class="lpsn-box-image">
			<img src="#">
		</div>
		<div class="lpsn-box-content">
			<p class="text">
				<span class="someone"></span>
				<span class="product-name"></span>
				<span class="time-ago"></span>
				<span class="country"></span>
			</p>
		</div>
	</div>
</section>